@@ -24,6 +24,9 @@ card_brand_map = {
     'debcabal': 108
 }
 
+inverse_card_brand_map = {v: k for k, v in card_brand_map.items()}
+
+
 def _format_card(response):
     return {
         'id': response['card']['id'],
@@ -38,10 +41,9 @@ def _format_card(response):
 
 
 def _format(response):
-    try:
+    if 'payment_method_id' in response and response['payment_method_id'] in card_brand_map:
         response['payment_method_id'] = str(card_brand_map[response['payment_method_id']])
-    except:
-        pass
+
     return {
         'id': response['id'],
         'transaction_amount': response['transaction_amount'],
@@ -49,7 +51,7 @@ def _format(response):
         'status': response['status'],
         'status_detail': response['status_detail'],
         'card': _format_card(response),
-        'payment_day': parse_date(response['date_created']) ,    # es igual a date_created
+        'payment_day': parse_date(response['date_created']),    # es igual a date_created
         'statement_descriptor': response['statement_descriptor'],
         'payment_method_id': response['payment_method_id'],
         'installments': response['installments']
@@ -87,6 +89,9 @@ class Payment(MuviBase):
             if f in payment_data:
                 payment_data_mp[f] = payment_data[f]
 
+        if 'payment_method_id' in payment_data_mp and payment_data_mp['payment_method_id'] in inverse_card_brand_map:
+            payment_data_mp['payment_method_id'] = inverse_card_brand_map[payment_data_mp['payment_method_id']]
+
         if 'payer' in payment_data:
             payment_data_mp["payer"] = {
                 "first_name": payment_data['payer']["nombre"],
